pub struct MetadataService { /* private fields */ }Expand description
A client that talks to the Google metadata service and gets tokens for the default service account.
This only will work on hosts that are within the GCP network.
See google_cloud_auth::credentials::mds for more details.
Implementations
Sourceimpl MetadataService
impl MetadataService
Sourcepub async fn metadata_endpoint_exists() -> Result<bool>
pub async fn metadata_endpoint_exists() -> Result<bool>
Verify whether the metadata.google.internal endpoint exists, and it returns a 2XX.
Sourcepub async fn new(
oauth_config: &OAuthConfig,
scopes: &[impl AsRef<str>],
) -> Result<MetadataService>
pub async fn new( oauth_config: &OAuthConfig, scopes: &[impl AsRef<str>], ) -> Result<MetadataService>
Attempt to create an auth client that will contact the metadata service if possible.
To verify that the metadata service is available, see Self::metadata_endpoint_exists